SunPy physics
*************

The physics submodule contains routines to calculate various physical parameters
and models for the Sun.

.. automodapi:: sunpy.physics

.. automodapi:: sunpy.physics.differential_rotation

.. automodapi:: sunpy.physics.solar_rotation
